@@ -16,14 +16,6 @@ RTOL = epsilon.small * 1000
 ATOL = epsilon.small
 
 
-def ldot(A, B):
-    return ddot(A, B, left=True)
-
-
-def dotr(A, B):
-    return ddot(A, B, left=False)
-
-
 class EP(object):
     r"""Expectation Propagation algorithm.
 
@@ -125,11 +117,6 @@ class EP(object):
             raise ValueError(msg)
 
         self._need_update = False
-        # self._logger.debug('EP loop has performed %d iterations.', i)
-
-    @property
-    def cache(self):
-        return self._cache
 
     @property
     def cav(self):
