@@ -23,23 +23,29 @@ class OffsetMean(Function):
     def value(self, x):
         r"""Offset function evaluated at ``x``.
 
-        Args:
-            x (array_like): sample ids.
+        Parameters
+        ----------
+        x : array_like
+            Sample ids.
 
-        Returns:
-            :math:`o \mathbf 1`.
+        Returns
+        -------
+        :math:`o \mathbf 1`.
         """
         x = asarray(x)
         return full(x.shape, self.variables().get('offset').value)
 
-    def gradient(self, x):  # pylint: disable=R0201
+    def gradient(self, x):
         r"""Offset function gradient.
 
-        Args:
-            x (array_like): sample ids.
+        Parameters
+        ----------
+        x : array_like
+            Sample ids.
 
-        Returns:
-            :math:`\mathbf 1`.
+        Returns
+        -------
+        :math:`\mathbf 1`.
         """
         x = asarray(x)
         return dict(offset=ones(x.shape))
