@@ -1,10 +1,13 @@
 from .check import check_economic_qs, check_covariates, check_outcome
 from .io import wprint
 from .hsolve import hsolve
+from .normalise import (normalise_outcome, normalise_covariance,
+                        normalise_covariates)
 
 log2pi = 1.837877066409345339081937709124758839607238769531250
 
 __all__ = [
     'check_economic_qs', 'check_covariates', 'check_outcome', 'wprint',
-    'hsolve'
+    'hsolve', 'normalise_outcome', 'normalise_covariance',
+    'normalise_covariates'
 ]
